netapp_ontap.models.zapp_s3_bucket_application_components_access_policies_conditions API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_s3_bucket_application_components_access_policies_conditions`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappS3BucketApplicationComponentsAccessPoliciesConditionsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappS3BucketApplicationComponentsAccessPoliciesConditions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `delimiters GET POST PATCH`

    The delimiters field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `max_keys GET POST PATCH`

    The max_keys field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `operator GET POST`

    Policy Condition Operator.

  `prefixes GET POST PATCH`

    The prefixes field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `source_ips GET POST PATCH`

    The source_ips field of the zapp_s3_bucket_application_components_access_policies_conditions.

  `usernames GET POST PATCH`

    The usernames field of the zapp_s3_bucket_application_components_access_policies_conditions.